#include "stdafx.h"

Client::Client(char* servername)
{
    szServerName = servername;
    ConnectSocket = INVALID_SOCKET;
};

bool Client::Start() 
{
    WSADATA wsaData;
 
    // Initialize Winsock
    int iResult = WSAStartup(MAKEWORD(2,2), &wsaData);
    if(iResult != 0)
    {
        printf("WSAStartup failed: %d\n", iResult);
        return false;
    }
 
    struct addrinfo *result = NULL, *ptr = NULL, hints;
 
    ZeroMemory(&hints, sizeof(hints));
    hints.ai_family = AF_UNSPEC;        
    hints.ai_socktype = SOCK_STREAM;    
    hints.ai_protocol = IPPROTO_TCP;
 
    // Resolve the server address and port
    iResult = getaddrinfo(szServerName, portNumber, &hints, &result);
    if (iResult != 0)
    {
        printf("getaddrinfo failed: %d\n", iResult);
        WSACleanup();
        return false;
    }
 
    ptr = result;
 
    // Create a SOCKET for connecting to server
    ConnectSocket = socket(ptr->ai_family, ptr->ai_socktype, ptr->ai_protocol);
 
    if (ConnectSocket == INVALID_SOCKET)
    {
        printf("Error at socket(): %d\n", WSAGetLastError());
        freeaddrinfo(result);
        WSACleanup();
        return false;
    }
 
    // Connect to server
    iResult = connect(ConnectSocket, ptr->ai_addr, (int)ptr->ai_addrlen);
 
    if (iResult == SOCKET_ERROR)
    {
        closesocket(ConnectSocket);
        ConnectSocket = INVALID_SOCKET;
    }
 
    freeaddrinfo(result);
 
    if (ConnectSocket == INVALID_SOCKET)
    {
        printf("Unable to connect to server!\n");
        WSACleanup();
        return false;
    }
 
    return true;
};

void Client::Stop() 
{
    int iResult = shutdown(ConnectSocket, SD_SEND);
 
    if (iResult == SOCKET_ERROR)
    {
        printf("shutdown failed: %d\n", WSAGetLastError());
    }
 
    closesocket(ConnectSocket);
    WSACleanup();
};

int Client::Send(char* szMsg, int sndPkgSize)
{
    int iResult = send(ConnectSocket, szMsg, sndPkgSize, 0);
    if (iResult == SOCKET_ERROR)
    {
        printf("send failed: %d\n", WSAGetLastError());
        Stop();
        return SOCKET_ERROR;
    }
    else if (iResult < sndPkgSize)
    {
        return SND_SOCKET_ERROR_SHORT_BUFFER;
    }
    else if (iResult > sndPkgSize)
    {
        return SND_SOCKET_ERROR_LONG_BUFFER;
    }
    printf("Sent: %i bytes\n", iResult);
    return iResult;
};

int Client::Recv(char* rcvPkg, int rcvPkgSize)
{
    int iResult = recv(ConnectSocket, rcvPkg, rcvPkgSize, 0);
    if (iResult == SOCKET_ERROR)
    {
        return SOCKET_ERROR;
    }
    else if (iResult < rcvPkgSize)
    {
        return RCV_SOCKET_ERROR_SHORT_BUFFER;
    }
    else if (iResult > rcvPkgSize)
    {
        return RCV_SOCKET_ERROR_LONG_BUFFER;
    }
    printf("Received: %i bytes\n", iResult);
    return iResult;
}
