#ifndef STRUCTS_H
#define STRUCTS_H

#define MAX_SIZE                        2048
#define SMALL_BUFFER_SIZE               256
#define MAX_RESPONSE_POINTS             200
#define SERIAL_NUMBER_BUFFER_SIZE       8
#define MAX_SENSOR_DESCRITIONS          12 
#define MAX_PARMS                       10

struct basicInfo
{
    long callId;                            // index that points to a particular function
    unsigned long eventId;                  // index identifying the event or call, set by client
    unsigned long nEventId;                 // event index notted, set by server
    long addr;                              // address of the sensor (client sets to zero if unused or it is a returned value)
    long inx;                               // index of the sensor (client sets to zero if unused or it is a returned value)
    char sn[SERIAL_NUMBER_BUFFER_SIZE];     // six char sensor serial number (client sets to null string if unused or is return value)
    long result;                            // the functions return value (zero by client, server returns value)
    long bigBufferUsed;                     // normally zero, but if data is sent or return via big buffer this value is set to used length
} typedef basicInfo_t;

long const basicInfoSize = sizeof(basicInfo_t);

struct tenLongs                             // use if a combination of zero to four longs or enum passed in addition to address, serial number or index 
{
    long longs[MAX_PARMS];
} typedef tenLongs_t;

struct tenDoubles                           // use if a combination of zero to four doubles passed in addition to address, serial number or index 
{
    long doubles[MAX_PARMS];
} typedef tenDoubles_t;

struct tenSNs                               // use if a combination of one to ten serial numbers are passed in addition to address, serial number or index 
{
    char snOne[SERIAL_NUMBER_BUFFER_SIZE];
    char snTwo[SERIAL_NUMBER_BUFFER_SIZE];
    char snThree[SERIAL_NUMBER_BUFFER_SIZE];
    char snFour[SERIAL_NUMBER_BUFFER_SIZE];
    char snFive[SERIAL_NUMBER_BUFFER_SIZE];
    char snSix[SERIAL_NUMBER_BUFFER_SIZE];
    char snSeven[SERIAL_NUMBER_BUFFER_SIZE];
    char snEight[SERIAL_NUMBER_BUFFER_SIZE];
    char snNine[SERIAL_NUMBER_BUFFER_SIZE];
    char snTen[SERIAL_NUMBER_BUFFER_SIZE];
} typedef tenSNs_t;

struct parms
{
    tenLongs_t lngs;
    tenDoubles_t dbls;
    tenSNs_t sns;
    long smallBufferSize;
    char smallBuffer[SMALL_BUFFER_SIZE];
} typedef parms_t;

struct snsrDesc
{
	long DeviceIndex;					            // 1..n
	long DeviceAddress;					            // 1..255
	char SerialNumber[SERIAL_NUMBER_BUFFER_SIZE];   // zero terminated string, 6 characters and a null ... make it eight for alignment purposes
} typedef snsrDesc_t;

struct snsrDescs
{
    long cnt;                               
    snsrDesc_t sd[MAX_SENSOR_DESCRITIONS];
} typedef snsrDescs_t;

struct normalPackage
{
    basicInfo_t basInf;
    union
    {
        parms_t prms;
        snsrDescs_t sd;
    };
} typedef normalPkg_t;

struct resposnePoint			            // structure used to create freqeuncy sensitive offsets or 
{										    // compensate for frequency response
	double frequency;					    // Hz
	double amplitude;					    // dB
} typedef rspPt_t;

struct responsePoints
{
    long cnt;
    long pts[MAX_RESPONSE_POINTS];              
} typedef rspPts_t;

struct responsePointsPackage
{
    basicInfo_t basInf;
    rspPts_t rPts;
} typedef rspPtsPkg_t;

struct bigBufferPackage
{
    basicInfo_t basInf;
    char bigBuffer[MAX_SIZE - basicInfoSize];
} typedef bigBufferPkg_t;

long const NORMAL_PACKAGE_SIZE = sizeof(normalPkg_t);
long const RESPONSE_POINTS_PACKAGE_SIZE = sizeof(rspPtsPkg_t);
long const BIG_BUFFER_PACKAGE_SIZE = sizeof(bigBufferPkg_t);

union package
{
    char allBytes[MAX_SIZE];
    normalPkg_t normalPkg;
    rspPtsPkg_t rspPtsPkg;
    bigBufferPkg_t bigBufferPkg;
} typedef pkg_t;

#endif
